@@ -28,14 +28,17 @@ $albumTitle = "xxx";
 // Хɽβ URL (ɬפʤж)
 $bannerImg = "";
 // ơ (Themes ǥ쥯ȥʲ CSS եΥե̾ʬ)
-$theme = "white";
+$theme = "brown";
 
 // ԥѥ
 $adminPass = "xxx";
 // TRUE:ԤΤ߿Ʋǽ, FALSE:ïǤ⿷Ʋǽ
 $adminOnly = TRUE;
+// Ʋǽʥե륵ξ(Хñ)
+$maxFileSize = 512;
+
 // ХԤ̾
 $adminName = "xxx";
 // ХԤΥ᡼륢ɥ쥹 (ɬפʤж)
-$adminMail = "xxx@xxx.xxx";
+$adminMail = "";
 ?>
